Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func List ¶
func List(ctx context.Context, c *gotwitter.GoTwitter, p *types.ListInput) (*types.ListOutput, error)
Return live or scheduled Spaces matching your specified search terms. This endpoint performs a keyword search, meaning that it will return Spaces that are an exact case-insensitive match of the specified search term. The search term will match the original title of the Space. https://developer.twitter.com/en/docs/twitter-api/spaces/search/api-reference/get-spaces-search
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.